#
# spec file for package golang-github-cpuguy83-go-md2man
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         cpuguy83
%global repo            go-md2man
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           golang-%{provider}-%{project}-%{repo}
Version:        2.0.0+git20190314.f79a8a8
Release:        2.2
Summary:        Convert markdown into man pages
License:        MIT
Group:          Development/Languages/Golang
URL:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.xz
Source1:        rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  golang-packaging
BuildRequires:  xz

%{go_nostrip}
%{go_provides}

%description
Tool to converts markdown into man pages.

%package -n go-md2man
Summary:        Tool to converts markdown into man pages
Group:          Development/Languages/Golang
Provides:       go-go-md2man = %{version}
AutoReqProv:    Off

%{go_exclusivearch}

%description -n go-md2man
Tool to converts markdown into man pages.

%prep
%setup -q -n %{repo}-%{version}

%build
%goprep %{import_path}
%gobuild --mod=vendor "" ...

%install
%goinstall
%gosrc
%gofilelist
mkdir -p %{buildroot}%{_mandir}/man1
../go/bin/go-md2man -in go-md2man.1.md -out %{buildroot}%{_mandir}/man1/go-md2man.1

%check
%gotest --mod=vendor "" ...

%files -f file.lst
%defattr(-,root,root,-)
%doc README.md
%license LICENSE.md

%files -n go-md2man
%defattr(-,root,root)
%{_bindir}/go-md2man
%{_mandir}/man1/go-md2man.1%{?ext_man}

%changelog
* Wed Oct 30 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Generete and package go-md2man man page.
* Wed Feb  5 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.0.0+git20190314.f79a8a8:
  * Psych, we only support go.11 and higher
  * Update readme
  * Use go modules and set import paths to /v2
  * Improvements to makefile
  * Use TRAVIS_GO_VERSION env var instead of matrix
  * Use golangci-lint
  * Update travis config for go versions
  * Don't run vendor validation in CI
  * Fix the example and typo
  * Fix links processing for v2
  * RenderNode: fix error printing
  * Fix table parsing/processing for v2
  * Fix list in list embedding
  * Update md2man to use blackfriday v2 API
  * Update vendoring to blackfriday v2 API
  * remove older versions of go from travis config
  * fix validate vendor script
  * More linters
  * Add errcheck to metalinter
  * Fix linting issues
  * set vendor check to executable
  * Add travis config
  * remove used processFooterText
  * Fix falal -> fatalf
  * Add TitleBlock test
  * gofmt roff.go
  * Update README details
  * Improve rendering of nested lists
  * dep ensure -upgrade to get v1.5 of blackfriday
  * converts project to use dep
  * Add some initial unit tests
  * Fix some table rendering issues for empty cells
  * Don't use CMD in Dockerfile
  * Add dockerfile
  * Fix tables displaying using tbl specification
- from version 1.0.10
  * Bumps blackfriday to 1.5.2
  * Some tidying up of CI, Makefile enhancements.
- from version 1.0.9
  * Use go modules instead of go dep
    + Everything is still vendored so build scripts should not fail
- from version 1.0.8
  * Improve testing
  * Improve rendering of nested lists - #30 @msimacek
- from version 1.0.7
  * Switch vendor tool to dep #29
  * Update blackfriday vendoring to v1.5 #29
- Update _service file
- Move LICENSE to %%license section
- Invoke %%gobuild with -mod=vendor "" to disable network access
- Remove s390x from ExcludeArch
* Wed Jun 13 2018 jmassaguerpla@suse.com
- since commit https://github.com/cpuguy83/go-md2man/commit/648eed146d3f3beacb64063cd0daae908015eebd#diff-a447edf0cfc23146457ff83dce52d372 there is a vendor directory and thus we don't need to
  require any external golang package.
* Thu Feb  1 2018 ro@suse.de
- do not build on s390, only on s390x (no go on s390)
* Fri Mar  3 2017 jmassaguerpla@suse.com
- add provides go-go-md2man
  this provides was there in previous versions and we can not remove
  it or otherwise it breaks dependent packages (i.e. docker, k8s)
* Wed Dec  7 2016 tboerger@suse.com
- Update to version 1.0.6+git20160904.a65d4d2:
  * Render raw html as is
  * Add html entity output support
  * fix escaping for curly braces
  * fix wrong type for Entity func
  * md2man usable as a library (again)
  * Improve man page rendering
  * use stdio for default input and output
  * improve link
  * add vendor
* Fri Dec  2 2016 tboerger@suse.com
- Recursively test all packages
* Fri Dec  2 2016 tboerger@suse.com
- Added rpmlintrc for common golang linting
* Fri Dec  2 2016 tboerger@suse.com
- Requires and BuildRequires for dependencies
* Fri Dec  2 2016 tboerger@suse.com
- Using the new golang-packaging now
* Fri Dec  2 2016 tboerger@suse.com
- Refactoed spec with a new unified layout
* Thu Dec  1 2016 jmassaguerpla@suse.com
- add golang-github-shurcool-sanitized_anchor_name-source dependency
* Thu Dec  1 2016 jmassaguerpla@suse.com
- add the generation of the source package. With go1.7 we need
  the source in order to build other golang-* which depend on this
  one.
* Sun Jan 17 2016 i@marguerite.su
- Update to version 1.0.5+git20160104.2724a9c:
  + md2man usable as a library (again)
  + Improve man page rendering
* Tue Jul 28 2015 i@marguerite.su
- rename to golang-github-cpuguy83-md2man
- update version 1.0.2+git20150617.e69ac41
- use golang-packaging for packaging
* Wed May 27 2015 dmacvicar@suse.de
- initial package for version 1.0.2
